/*  ---------------------------------------------------------------------------
    Program  :  UnevenAxDemo.sas

    Purpose  :  Create a dithered line plot with an uneven axis where unlabeled
                ticks at regular intervals have been removed. 

    Input    :  psd.MouseUnevenInterval
    Output   :  demo1.cgm and demo2.cgm for distribution
    ------------------------------------------------------------------------  */
    options nodate number pageno=1 fmtsearch=(work) mautosource nomprint nosymbolgen;
    options sasautos=(sasautos 'c:\N08\CustomAxis\Mac'); 
    libname psd 'c:\N08\CustomAxis\Data';
    title1 move=(+10pct,+0pct) 'Mouse Tumor Growth Study';
    %let output=C:\N08\CustomAxis\grf;

/******
 SUMMARY DATA ARE USED TO PRODUCE THE VERTICAL SEGMENTS OF THE LINE PLOT, BECAUSE THE
 CGM GRAPHICS DEVICE DOES NOT COORDINATE LINE AND 'TOP' WIDTHS. (TOPS ARE MUCH TOO WIDE).
*****/
    proc summary data=psd.MouseUnevenInterval NOPRINT;
     by day;
     var LeftT RightT;
     output out=VerticalLines MEAN=LTMean RTMean STDERR=LTSTD RTSTD;
    run;

    data VerticalLines(keep=day ditherDay flank TstdMinus Tmean TstdPlus);
     set VerticalLines;
     length flank $5;
     flank='Left';  Tmean=LTMean; TstdPlus=LTmean+LTstd; TstdMinus=LTmean-LTstd; 
       ditherday=day-0.35; /*WHERE DITHERING OCCURS */
       output;
     flank='Right'; Tmean=RTMean; TstdPlus=RTmean+RTstd; TstdMinus=RTmean-RTstd;
       ditherday=day+0.35; /*WHERE DITHERING OCCURS */
       output;
    run;

    data annoVerticalLines;
     length style function $8;
     retain style 'HWCGM001' line 1; 
     retain when 'a'; 
     retain tickwidth 2.25 linewidth 0.3;
     set VerticalLines;
      hsys='3'; xsys='2';
      if flank eq 'Left' then color='CX0386BE'; else color='CX866C00'; /* NESUG 08 COLORS */
      ysys='2'; function='move'; y=TstdPlus; x=ditherDay; output;
      ysys='9'; function='draw'; y=-0.3; size=tickwidth; output;
      ysys='2'; function='draw'; y=TstdMinus; size=linewidth; output;
      ysys='9'; function='draw'; y=-0.3; size=tickwidth; output;
      color='black'; 
      ysys='2'; function='symbol'; style='none'; text='dot'; size=1.8; y=Tmean; output;
    run;

/* NEED CALCXMIN AND CALCXMAX MACRO VARIABLES FOR MACRO MKUNDERLYINGSCALE INVOKED LATER ON */
    proc sql noprint;
      select min(ditherday), max(ditherday) into :calcXmin, :calcXmax
      from verticalLines;
    quit;

/* GRAPHICS OUTPUT */
    goptions reset=goptions;
    goptions device=cgmOf97L gunit=pct rotate=landscape ftext=HWCGM001
    htext=3 htitle=3.5 display;

/* VERTICAL AXIS */
    axis1 w=3 label=(f=HWCGM002 a=90 "Tumor Size") 
     order=(0 to 1600 BY 400) major=(h=1.2) minor=(h=0.6 n=1);

/* HORIZONTAL AXES*/
    axis2
      w=1 order=(%MkUnderlyingScale(calcXMin=&calcXMin, calcXMax=&calcXMax))
      label=none major=none minor=none value=none origin=(,12.5 pct);
/* MAKE ROOM FOR "FOLLOW-UP" WITH AN ADJUSTMENT TO %MkUnderlyingScale */
    axis3
      w=1 order=(%MkUnderlyingScale(calcXMin=&calcXMin, calcXMax=&calcXMax, minOffset=1, maxOffset=6))
      label=none major=none minor=none value=none origin=(,12.5 pct);

/* FOR HORIZONTAL DATA LINES ONLY */
    symbol1 interpol=j l=1 w=3 c=CX0386BE value=none;
    symbol2 interpol=j l=1 w=3 c=CX866C00 value=none;

/* LEGEND FOR THE DITHERED DATA */
    legend1 noframe down=2 
      position=(LEFT INSIDE TOP) offset=(+2pct,)
	     label=(f=HWCGM001 "Flank")
		    shape=line(3pct)
      value=(t=1 j=l h=2.5 "Left"
             t=2 j=l h=2.5 "Right");

/*****
 CREATE ANNOTATE DATASET, WORK.ANNOAXIX INSIDE THE UNEVENINTERVALAXIS MACRO. &INDS STORES
 COORDINATES AND LABELS FOR THE DISPLAYED, UNEVEN INTERVAL AXIS. THE UNDITHERED VARIABLE
 'DAY' IS ASSIGNED TO THE PARAMETER, XVAR.
*****/
    %UnevenIntervalAxis(inDS=verticalLines, xvar=day, pctSize=3, xlabel=Days on Study, yOrigin=12.5)
    filename demo1 "&output.\demo1.cgm";
    goptions gsfname=demo1;
    proc gplot data=verticalLines annotate=annoVerticalLines;
      plot Tmean*ditherday=flank /vaxis=axis1 haxis=axis2 noframe legend=legend1 annotate=annoAxisX;
      format Tmean comma6.;
    run;
    quit;

/* FORMAT THE AXIS VALUES WITH XVALFMT FILLED IN ON %UNEVENINTERVAL*/
    proc format;
     value xaxisFM 13,16,18,20,26,30=[2.] 40='Follow-up';
    run;
    %UnevenIntervalAxis(inDS=verticalLines, xvar=day, pctSize=3, xlabel=Days on Study, 
                      yOrigin=12.5, xvalfmt=xaxisFM.)
    filename demo2 "&output.\demo2.cgm";
    goptions gsfname=demo2;
    proc gplot data=verticalLines annotate=annoVerticalLines;
      plot Tmean*ditherday=flank /vaxis=axis1 haxis=axis3 noframe legend=legend1 annotate=annoAxisX;
      format Tmean comma6.;
    run;
    quit;
